@@ -50,6 +50,8 @@ class DBTypes(Enum):
     decimal = 5
     bool = 6
     single_item = 7
+    out_integer = 4
+    out_bool = 6
 
 
 def get_map_type(r_type: DBTypes) -> Callable:
